<img
  src="{{ src }}"
  {%- if srcset %}
  srcset="{{ srcset }}"
  {%- endif %}
  {%- if sizes %}
  sizes="{{ sizes }}"
  {%- endif %}
  alt="{{ alt }}"
  width="{{ width }}"
  {%- if height %}
  height="{{ height }}"
  {%- endif %}
  loading="{{ loading }}"
  {%- for attr_name, attr_value in attrs.items() %}
  {{ attr_name }}="{{ attr_value }}"
  {%- endfor %}
/>
